# RailgunS

[![Downloads](https://pepy.tech/badge/railguns)](https://pepy.tech/project/railguns)
[![PyPI](https://img.shields.io/pypi/v/railguns)](https://pypi.org/project/RailgunS/)
[![Python](https://img.shields.io/pypi/pyversions/railguns)](https://www.python.org)
[![Django](https://img.shields.io/pypi/djversions/railguns)](https://www.djangoproject.com)
[![License](https://img.shields.io/pypi/l/railguns)](https://opensource.org/licenses/MIT)

Only My Railgun

---

## Installation

```shell
pip3 install railguns
```

## Vendor

框架用到的库

- [Django](https://www.djangoproject.com)
- [Django REST framework](https://www.django-rest-framework.org)
- [Simple JWT](https://github.com/davesque/django-rest-framework-simplejwt)

部署

- [Gunicorn](https://www.gunicorn.org)
- [uvicorn](https://www.uvicorn.org)

常用库

- [Django CKEditor 5](https://github.com/hvlads/django-ckeditor-5)
- [Django Filter](https://django-filter.readthedocs.io)
- [django-htmlmin](https://github.com/cobrateam/django-htmlmin)
- [mysql-connector-python](https://dev.mysql.com/doc/connector-python/en/connector-python-django-backend.html)
- [redis-py](https://github.com/redis/redis-py)

## License

RailgunS is released under the MIT license. [See LICENSE](https://github.com/nyssance/railguns/blob/main/LICENSE) for details.
